@@ -31,5 +31,7 @@ module R10K::Module
 
   require 'r10k/module/base'
   require 'r10k/module/git'
+  require 'r10k/module/svn'
+  require 'r10k/module/local'
   require 'r10k/module/forge'
 end
